@@ -50,8 +50,8 @@ view_selection_func(GtkTreeSelection *selection, GtkTreeModel *model,
     tag_t *tag;
     gtk_tree_model_get(model, &iter, TAG_COL_DATA, &tag, -1);
 
-      /* you just cannot delete or edit the "created_by" tag */
-    if(strcasecmp(tag->key, "created_by") == 0) {
+    /* you just cannot delete or edit the "created_by" tag */
+    if(!tag || strcasecmp(tag->key, "created_by") == 0) {
       list_button_enable(context->list, LIST_BUTTON_REMOVE, FALSE);
       list_button_enable(context->list, LIST_BUTTON_EDIT, FALSE);
     } else {
@@ -219,6 +219,7 @@ static void on_tag_last(GtkWidget *button, tag_context_t *context) {
 }
 
 static void on_tag_add(GtkWidget *button, tag_context_t *context) {
+
   /* search end of tag chain */
   tag_t **tag = context->tag;
   while(*tag) 
@@ -316,6 +317,7 @@ static GtkWidget *tag_widget(tag_context_t *context) {
   list_set_store(context->list, context->store);
 
   GtkTreeIter iter;
+
   tag_t *tag = *context->tag;
   while(tag) {
     /* Append a row and fill in some data */
