@@ -55,12 +55,14 @@ typedef struct {
 
 } list_priv_t;
 
+#if 1
 #if defined(USE_HILDON) && (MAEMO_VERSION_MAJOR == 5)
-#define FREMANTLE
+#define FREMANTLE_PANNABLE_AREA
 #include <hildon/hildon-gtk.h>
 #include <hildon/hildon-pannable-area.h>
 // #define FREMANTLE_USE_POPUP
 #endif
+#endif
 
 #ifdef FREMANTLE_USE_POPUP
 
@@ -318,7 +320,7 @@ void list_set_static_buttons(GtkWidget *list, int flags,
   if(cb_new) {
     priv->button.widget[0] = 
       gtk_button_new_with_label(_((flags&LIST_BTN_NEW)?"New":"Add"));
-#ifdef FREMANTLE
+#ifdef FREMANTLE_PANNABLE_AREA
     if(flags & LIST_BTN_BIG)
       hildon_gtk_widget_set_theme_size(priv->button.widget[0], 
 	       (HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH));
@@ -425,10 +427,10 @@ GtkWidget *list_new(void)
   g_signal_connect(G_OBJECT(vbox), "destroy",
 		   G_CALLBACK(on_list_destroy), priv);
 
+#ifndef FREMANTLE_PANNABLE_AREA
   priv->view = gtk_tree_view_new();
-#ifdef FREMANTLE
-  hildon_gtk_tree_view_set_ui_mode(GTK_TREE_VIEW(priv->view), 
-				   HILDON_UI_MODE_EDIT);
+#else
+  priv->view = hildon_gtk_tree_view_new(HILDON_UI_MODE_EDIT);
 #endif
 
 #ifdef USE_HILDON
@@ -440,9 +442,9 @@ GtkWidget *list_new(void)
  
   gtk_tree_selection_set_select_function(
 	 gtk_tree_view_get_selection(GTK_TREE_VIEW(priv->view)), 
-	 list_selection_function, vbox, NULL);
+  	 list_selection_function, vbox, NULL);
 
-#ifndef FREMANTLE
+#ifndef FREMANTLE_PANNABLE_AREA
   /* put view into a scrolled window */
   GtkWidget *scrolled_window = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window), 
